==> deepin-image-viewer_1.3.8.orig.tar.gz: deepin-image-viewer-1.3.8/CHANGELOG.md <==
<a name="1.3.8"></a>
## 1.3.8 (2019-01-25)


#### Bug Fixes

*   a crash in ImageWidget::event ([90dc30b0](https://github.com/linuxdeepin/deepin-image-viewer/commit/90dc30b08a06a4ce06b53d1fd0dd096a8f19cd2f))



<a name="1.3.7"></a>
##  1.3.7 (2019-01-03)


#### Features

*   support open svg ([86527b70](https://github.com/linuxdeepin/deepin-image-viewer/commit/86527b70dace2c644fe70c8c7bab19fa373dbd8b))
*   add swipe to go preview/next support ([14fb8336](https://github.com/linuxdeepin/deepin-image-viewer/commit/14fb8336f3dcbf1c62857e9528e85918c89db106))
*   add pinch to zoom gesture ([ab865ddc](https://github.com/linuxdeepin/deepin-image-viewer/commit/ab865ddcc517eaf0f9fedc19485c13dced492d00))
*   zoom under the cursor ([5869b709](https://github.com/linuxdeepin/deepin-image-viewer/commit/5869b709006756cc909b2b264e749ec1dc97ce48))

#### Bug Fixes

*   use build version. ([b8c63818](https://github.com/linuxdeepin/deepin-image-viewer/commit/b8c63818b93454f324c3d9519ace2a281d0d995b))
*   navigation bar close button. ([8a401acd](https://github.com/linuxdeepin/deepin-image-viewer/commit/8a401acdce9e442ed0c009fe09bafe02bc1f0af9))
*   fullscreen right menu cursor. ([14b1811d](https://github.com/linuxdeepin/deepin-image-viewer/commit/14b1811d8866a1d7fed68d4524507f88b7aac666))
*   image view cursor. ([6bbaa98f](https://github.com/linuxdeepin/deepin-image-viewer/commit/6bbaa98f64bd120c375e948f64d4e592d4881206))
*   fit the image to window. ([7b87149a](https://github.com/linuxdeepin/deepin-image-viewer/commit/7b87149a1f2b661f8013319c1b38db771f8ef885))



<a name="1.3.6"></a>
## 1.3.6 (2018-12-11)




<a name="1.3.5"></a>
## 1.3.5 (2018-12-06)


#### Bug Fixes

*   the "Ctrl+C" shortcut is invalid ([e64adeca](https://github.com/linuxdeepin/deepin-image-viewer/commit/e64adeca7bd39f8dcbd3f49131a838528d489f64))



<a name="1.3.4"></a>
## 1.3.4 (2018-12-06)


#### Bug Fixes

*   decide image format form the image file content ([b2aa1c25](https://github.com/linuxdeepin/deepin-image-viewer/commit/b2aa1c25663283a4d1807982dcf5f7a4d75a758f))
*   open the current path when the command lines is empty ([40c2618d](https://github.com/linuxdeepin/deepin-image-viewer/commit/40c2618d4a4f1bd1dae1fca7713b923bcf63d63f))



<a name="1.3.3"></a>
## 1.3.3 (2018-11-30)


#### Features

*   support print preview ([c5c1cfef](https://github.com/linuxdeepin/deepin-image-viewer/commit/c5c1cfefada0fcd67d697620a6be51fae8e6f37c))



<a name="1.3.2"></a>
## 1.3.2 (2018-11-23)


#### Bug Fixes

*   Update ts file and deepin vendor support ([230551db](https://github.com/linuxdeepin/deepin-image-viewer/commit/230551dbe2be6a6747cf8814eb39a383fa07850c))

#### Features

*   use the file name sort the image list ([55f7a87c](https://github.com/linuxdeepin/deepin-image-viewer/commit/55f7a87cba23f789afefd8684064cb3601cbe6c2))
*   support the recent file spec. ([9e164ebb](https://github.com/linuxdeepin/deepin-image-viewer/commit/9e164ebb99c17860fe21b93b143c425bdb1dc962))



<a name="1.3.1"></a>
## 1.3.1 (2018-11-08)


#### Bug Fixes

*   empty command can start a new window ([577ec38b](https://github.com/linuxdeepin/deepin-image-viewer/commit/577ec38b2b4378113c44e2286b2ca668dc57c11e))
*   shortcut preview info is empty ([239c9c9a](https://github.com/linuxdeepin/deepin-image-viewer/commit/239c9c9a8de61f5d0f3cbf5a05d7b009a4c68f38))
*   shortcut is invalid ([74e17db2](https://github.com/linuxdeepin/deepin-image-viewer/commit/74e17db2fe4d869bb7d78697ad9666b58553a2ef))



<a name="1.3.0"></a>
## 1.3.0 (2018-10-24)


#### Features

*   add logo on topbar ([f2f70f5f](https://github.com/linuxdeepin/deepin-image-viewer/commit/f2f70f5f7c4ee4cf966bd3c21edeccbf0e41b716))

#### Bug Fixes

*   crash when press "Delete" ([8c67acc9](https://github.com/linuxdeepin/deepin-image-viewer/commit/8c67acc99a5d55fe39a0523aae71216475678c68))
*   remove dtk old interface. ([59ec8eb6](https://github.com/linuxdeepin/deepin-image-viewer/commit/59ec8eb67982b0862071639042fd15d32e60aaac))



<a name="1.2.23"></a>
### 1.2.23 (2018-07-20)


#### Bug Fixes

*   memory leak ([d680e97c](https://github.com/linuxdeepin/deepin-image-viewer/commit/d680e97c63df617b34bdda0dd3aaa3d2bb347caa))



<a name="1.2.22"></a>
## 1.2.22 (2018-05-24)


#### Bug Fixes

*   don't restore cursor. ([6f81631e](6f81631e))
* **flatpak:**  default save path error in flatpak environment ([699b4ae6](699b4ae6))



<a name="1.2.21"></a>
## 1.2.21 (2018-05-15)

*   Fix image is empty


<a name="1.2.20"></a>
## 1.2.20 (2018-05-14)


#### Bug Fixes

*   can't print image in landscape mode ([a63841a3](a63841a3))



<a name="1.2.19"></a>
### 1.2.19 (2018-04-11)


#### Features

* **print_dialog:**  add image settings option. ([53a8c772](53a8c772))



<a name="1.2.18"></a>
### 1.2.18 (2018-03-22)


#### Features

*   set wallpaper with dbus in flatpak ([30b00248](30b00248))

#### Bug Fixes

*   favorite menu and title states not synced ([2b16ceaa](2b16ceaa))

<a name="1.2.17"></a>
## 1.2.17 (2018-03-15)


#### Features

*   add notice for tif ([60e5a2da](60e5a2da))
*   add manual id ([65408f0b](65408f0b))
*   imageutils cutSquareImage support hidpi ([67fcbbb7](67fcbbb7))

#### Bug Fixes

*   toast hide failed ([9955ccfb](9955ccfb))
*   cleared item can be shown again ([afbc2b45](afbc2b45))
*   remove stays-on-top hint from scan dialog ([7c559016](7c559016))
*   build failed on static build ([c917a434](c917a434))
*   set titlebar background transparent ([c9dc6da9](c9dc6da9))
*   set pixmap device pixel ratio to device pixel ratio of window ([c792a3d5](c792a3d5))
*   remove seek operation ([b2019875](b2019875))
*   dxcb workaround ([c9cc715a](c9cc715a))
*   Adapt lintian ([dcad7f8a](dcad7f8a))
*   hide image on press super+d ([ca79cd62](ca79cd62))
*   set wallpaper by dde dbus ([b6f9a64c](b6f9a64c))
*   mainwindow button now showing on dark mode ([af0ff636](af0ff636))
*   Replace dbus-send with QDBusInterface ([86599aa4](86599aa4))
*   skip de check for flatpak ([3655aa3c](3655aa3c))
*   fix install path ([efefd53e](efefd53e))
*   setting wallpaper(convert the image's format). ([646d32c7](646d32c7))
* **hidpi:**
  *  top-left mainwindow icon not scaled ([54c971f8](54c971f8))
  *  some widgets are not showing clear ([4ba95264](4ba95264))
  *  some parts are not shown very clear ([4910a8af](4910a8af))
* **slideshow:**  cursor not showing with menu ([bd1e3499](bd1e3499))
* **timeline:**
  *  menu content changed after showing ([6b306252](6b306252))
  *  timeline date not showing ([3116dd53](3116dd53))

==> deepin-image-viewer_5.0.0.orig.tar.gz: deepin-image-viewer-5.0.0/CHANGELOG.md <==
<a name="1.3.17"></a>
## 1.3.17 (2019-06-11)


#### Bug Fixes

*   use QPrintPropertiesDialog replace QPageSetupDialog ([0c7fe450](https://github.com/linuxdeepin/deepin-image-viewer/commit/0c7fe450f7dc7048bb7334620eadf26cb2064bfe))



<a name="1.3.14"></a>
## 1.3.14 (2019-05-23)


#### Features

*   remember last choosed path ([5c78c745](https://github.com/linuxdeepin/deepin-image-viewer/commit/5c78c74523f09623248e8c398402815cc2582d9f))

#### Others

*   remove unused code ([d0ecd9f3](https://github.com/linuxdeepin/deepin-image-viewer/commit/d0ecd9f31acd42cb977cf39a912e64fe78257c54))



<a name="1.3.13"></a>
## 1.3.13 (2019-04-19)


#### Bug Fixes

*   can not copy images to windows applications ([539b68d6](https://github.com/linuxdeepin/deepin-image-viewer/commit/539b68d6017d6c3de5f7bc26465057065777377a))



<a name="1.3.12"></a>
### 1.3.12 (2019-04-16)


#### Bug Fixes

*   not using color printing even if printers supports it ([560e3350](https://github.com/linuxdeepin/deepin-image-viewer/commit/560e3350e4419a0891290251c8304ba5ec393fd4))



<a name="1.3.11"></a>
## 1.3.11 (2019-04-10)


#### Bug Fixes

*   #16; QSqlDatabase and QSqlQuery thread-safety problem, used QMutexLocker; DBManager (#17) ([f0e9ff83](https://github.com/linuxdeepin/deepin-image-viewer/commit/f0e9ff83e58b3431670aa78a338d1f87011e3d0c))

#### Others

*   auto pull translation files from transifex ([c22ddcf0](https://github.com/linuxdeepin/deepin-image-viewer/commit/c22ddcf079a5f0d247ac9acb0d21c97b7c0c531f))
*   improve english ([f17bee54](https://github.com/linuxdeepin/deepin-image-viewer/commit/f17bee54e689e123c95bebce18f3c70fc62b6f58))
*   translation update. (#37) ([3ae7b257](https://github.com/linuxdeepin/deepin-image-viewer/commit/3ae7b257f4f6596bfecf5e53f70f3d1ea30139b8))



<a name="1.3.10"></a>
## 1.3.10 (2019-03-27)


#### Bug Fixes

*   forward the navigation wheel event of the NavigationWidget to the ImageView ([6832fb9c](https://github.com/linuxdeepin/deepin-image-viewer/commit/6832fb9c05c9dd6cdf755c0e98831a6f698b61f2))



<a name="1.3.9"></a>
## 1.3.9 (2019-03-27)


#### Others

*   save dpkg-parsechangelog calls in debian/rules ([478e87c3](https://github.com/linuxdeepin/deepin-image-viewer/commit/478e87c3cebaa11da7cd41a972be37335b5c3133))

#### Bug Fixes

*   freeimage plugin caused crash ([9b8df754](https://github.com/linuxdeepin/deepin-image-viewer/commit/9b8df754f2664a5087a96550400ef3acb49a800d))



<a name="1.3.8"></a>
## 1.3.8 (2019-01-25)


#### Bug Fixes

*   a crash in ImageWidget::event ([90dc30b0](https://github.com/linuxdeepin/deepin-image-viewer/commit/90dc30b08a06a4ce06b53d1fd0dd096a8f19cd2f))



<a name="1.3.7"></a>
##  1.3.7 (2019-01-03)


#### Features

*   support open svg ([86527b70](https://github.com/linuxdeepin/deepin-image-viewer/commit/86527b70dace2c644fe70c8c7bab19fa373dbd8b))
*   add swipe to go preview/next support ([14fb8336](https://github.com/linuxdeepin/deepin-image-viewer/commit/14fb8336f3dcbf1c62857e9528e85918c89db106))
*   add pinch to zoom gesture ([ab865ddc](https://github.com/linuxdeepin/deepin-image-viewer/commit/ab865ddcc517eaf0f9fedc19485c13dced492d00))
*   zoom under the cursor ([5869b709](https://github.com/linuxdeepin/deepin-image-viewer/commit/5869b709006756cc909b2b264e749ec1dc97ce48))

#### Bug Fixes

*   use build version. ([b8c63818](https://github.com/linuxdeepin/deepin-image-viewer/commit/b8c63818b93454f324c3d9519ace2a281d0d995b))
*   navigation bar close button. ([8a401acd](https://github.com/linuxdeepin/deepin-image-viewer/commit/8a401acdce9e442ed0c009fe09bafe02bc1f0af9))
*   fullscreen right menu cursor. ([14b1811d](https://github.com/linuxdeepin/deepin-image-viewer/commit/14b1811d8866a1d7fed68d4524507f88b7aac666))
*   image view cursor. ([6bbaa98f](https://github.com/linuxdeepin/deepin-image-viewer/commit/6bbaa98f64bd120c375e948f64d4e592d4881206))
*   fit the image to window. ([7b87149a](https://github.com/linuxdeepin/deepin-image-viewer/commit/7b87149a1f2b661f8013319c1b38db771f8ef885))



<a name="1.3.6"></a>
## 1.3.6 (2018-12-11)




<a name="1.3.5"></a>
## 1.3.5 (2018-12-06)


#### Bug Fixes

*   the "Ctrl+C" shortcut is invalid ([e64adeca](https://github.com/linuxdeepin/deepin-image-viewer/commit/e64adeca7bd39f8dcbd3f49131a838528d489f64))



<a name="1.3.4"></a>
## 1.3.4 (2018-12-06)


#### Bug Fixes

*   decide image format form the image file content ([b2aa1c25](https://github.com/linuxdeepin/deepin-image-viewer/commit/b2aa1c25663283a4d1807982dcf5f7a4d75a758f))
*   open the current path when the command lines is empty ([40c2618d](https://github.com/linuxdeepin/deepin-image-viewer/commit/40c2618d4a4f1bd1dae1fca7713b923bcf63d63f))



<a name="1.3.3"></a>
## 1.3.3 (2018-11-30)


#### Features

*   support print preview ([c5c1cfef](https://github.com/linuxdeepin/deepin-image-viewer/commit/c5c1cfefada0fcd67d697620a6be51fae8e6f37c))



<a name="1.3.2"></a>
## 1.3.2 (2018-11-23)


#### Bug Fixes

*   Update ts file and deepin vendor support ([230551db](https://github.com/linuxdeepin/deepin-image-viewer/commit/230551dbe2be6a6747cf8814eb39a383fa07850c))

#### Features

*   use the file name sort the image list ([55f7a87c](https://github.com/linuxdeepin/deepin-image-viewer/commit/55f7a87cba23f789afefd8684064cb3601cbe6c2))
*   support the recent file spec. ([9e164ebb](https://github.com/linuxdeepin/deepin-image-viewer/commit/9e164ebb99c17860fe21b93b143c425bdb1dc962))



<a name="1.3.1"></a>
## 1.3.1 (2018-11-08)


#### Bug Fixes

*   empty command can start a new window ([577ec38b](https://github.com/linuxdeepin/deepin-image-viewer/commit/577ec38b2b4378113c44e2286b2ca668dc57c11e))
*   shortcut preview info is empty ([239c9c9a](https://github.com/linuxdeepin/deepin-image-viewer/commit/239c9c9a8de61f5d0f3cbf5a05d7b009a4c68f38))
*   shortcut is invalid ([74e17db2](https://github.com/linuxdeepin/deepin-image-viewer/commit/74e17db2fe4d869bb7d78697ad9666b58553a2ef))



<a name="1.3.0"></a>
## 1.3.0 (2018-10-24)


#### Features

*   add logo on topbar ([f2f70f5f](https://github.com/linuxdeepin/deepin-image-viewer/commit/f2f70f5f7c4ee4cf966bd3c21edeccbf0e41b716))

#### Bug Fixes

*   crash when press "Delete" ([8c67acc9](https://github.com/linuxdeepin/deepin-image-viewer/commit/8c67acc99a5d55fe39a0523aae71216475678c68))
*   remove dtk old interface. ([59ec8eb6](https://github.com/linuxdeepin/deepin-image-viewer/commit/59ec8eb67982b0862071639042fd15d32e60aaac))



<a name="1.2.23"></a>
### 1.2.23 (2018-07-20)


#### Bug Fixes

*   memory leak ([d680e97c](https://github.com/linuxdeepin/deepin-image-viewer/commit/d680e97c63df617b34bdda0dd3aaa3d2bb347caa))



<a name="1.2.22"></a>
## 1.2.22 (2018-05-24)


#### Bug Fixes

*   don't restore cursor. ([6f81631e](6f81631e))
* **flatpak:**  default save path error in flatpak environment ([699b4ae6](699b4ae6))



<a name="1.2.21"></a>
## 1.2.21 (2018-05-15)

*   Fix image is empty


<a name="1.2.20"></a>
## 1.2.20 (2018-05-14)


#### Bug Fixes

*   can't print image in landscape mode ([a63841a3](a63841a3))



<a name="1.2.19"></a>
### 1.2.19 (2018-04-11)


#### Features

* **print_dialog:**  add image settings option. ([53a8c772](53a8c772))



<a name="1.2.18"></a>
### 1.2.18 (2018-03-22)


#### Features

*   set wallpaper with dbus in flatpak ([30b00248](30b00248))

#### Bug Fixes

*   favorite menu and title states not synced ([2b16ceaa](2b16ceaa))

<a name="1.2.17"></a>
## 1.2.17 (2018-03-15)


#### Features

*   add notice for tif ([60e5a2da](60e5a2da))
*   add manual id ([65408f0b](65408f0b))
*   imageutils cutSquareImage support hidpi ([67fcbbb7](67fcbbb7))

#### Bug Fixes

*   toast hide failed ([9955ccfb](9955ccfb))
*   cleared item can be shown again ([afbc2b45](afbc2b45))
*   remove stays-on-top hint from scan dialog ([7c559016](7c559016))
*   build failed on static build ([c917a434](c917a434))
*   set titlebar background transparent ([c9dc6da9](c9dc6da9))
*   set pixmap device pixel ratio to device pixel ratio of window ([c792a3d5](c792a3d5))
*   remove seek operation ([b2019875](b2019875))
*   dxcb workaround ([c9cc715a](c9cc715a))
*   Adapt lintian ([dcad7f8a](dcad7f8a))
*   hide image on press super+d ([ca79cd62](ca79cd62))
*   set wallpaper by dde dbus ([b6f9a64c](b6f9a64c))
*   mainwindow button now showing on dark mode ([af0ff636](af0ff636))
*   Replace dbus-send with QDBusInterface ([86599aa4](86599aa4))
*   skip de check for flatpak ([3655aa3c](3655aa3c))
*   fix install path ([efefd53e](efefd53e))
*   setting wallpaper(convert the image's format). ([646d32c7](646d32c7))
* **hidpi:**
  *  top-left mainwindow icon not scaled ([54c971f8](54c971f8))
  *  some widgets are not showing clear ([4ba95264](4ba95264))
  *  some parts are not shown very clear ([4910a8af](4910a8af))
* **slideshow:**  cursor not showing with menu ([bd1e3499](bd1e3499))
* **timeline:**
  *  menu content changed after showing ([6b306252](6b306252))
  *  timeline date not showing ([3116dd53](3116dd53))
